@@ -35,4 +35,18 @@ mutable struct RsvgDimensionData
     ex::Float64
 end
 
-RsvgDimensionData() = RsvgDimensionData(0,0,0,0)
\ No newline at end of file
+RsvgDimensionData() = RsvgDimensionData(0,0,0,0)
+
+"""
+RsvgRectangle is a simple struct of:
+    height::Float64
+    width::Float64
+    x::Float64
+    y::Float64
+"""
+mutable struct RsvgRectangle
+    height::Float64
+    width::Float64
+    x::Float64
+    y::Float64
+end
